@@ -1,5 +1,8 @@
 
 "pedplot"<-function(Pedig, affected=NULL, status=NULL, label="Indiv", ...){
+  PedigAsDataTable <- "data.table" %in% class(Pedig)
+  Pedig <- as.data.frame(Pedig)
+  if(PedigAsDataTable){setDF(Pedig)}
   id <- apply(Pedig[,label, drop=FALSE], 1, paste, collapse ="\n")
   if(is.null(affected) & ("keep" %in% colnames(Pedig))){affected<-Pedig$keep}
   if(is.null(status) & !is.null(affected) & ("Breed" %in% colnames(Pedig))){status<-!(Pedig$Breed%in%Pedig[affected>0,"Breed"])}
