@@ -5,19 +5,23 @@
 using namespace Rcpp;
 
 // [[Rcpp::depends(RcppArmadillo)]]
-
+// [[Rcpp::plugins(cpp11)]]
 // [[Rcpp::export]]
 
-Rcpp::NumericMatrix rcpp_segIBDandN(std::string pathThisBreed, std::string pathNative, int NFileC, int NFileN, const arma::ivec& ArmaIndexC, const arma::ivec& ArmaIndexN, int NC, int M, int minSNP, double minL, const arma::vec& ArmaPos, const arma::vec& Armakb, double a, char symB, int skip, int cskip) {
+Rcpp::NumericMatrix rcpp_segIBDandN(std::string pathThisBreed, std::string pathNative, int NFileC, int NFileN, const arma::ivec& ArmaIndexC, const arma::ivec& ArmaIndexN, int NC, int M, int minSNP, double minL, const arma::vec& ArmaPos, const arma::vec& Armakb, double a, std::string stdsymB, int skip, int cskip) {
   /* ***** initialize variables ****** */
   int m, i, j, r, r2, rK, endoffile, gleich;
   double L;
-  char str1[100], Line[2000000];
+  char str1[100];
   FILE *fC, *fN;
+  char symB = stdsymB.at(0);
   Rcpp::NumericMatrix confROH(NC, NC);
-  
   int K  = (minSNP<=60)?(minSNP/2):(30);
 
+  size_t bufsize = 2*(NFileC+NFileN);  
+  char* Line = (char*)malloc(bufsize*sizeof(char));
+  if(Line == NULL){error_return("Memory allocation failed.");};
+  
   int** Nat         = (int**)calloc(M,sizeof(int*));                   /*  M xNC - matrix */
   double** fROH     = (double**)calloc(NC,sizeof(double*));            /*  NCxNC - matrix */
   int** thisROH     = (int**)calloc(NC,sizeof(int*));                  /*  NCxNC - matrix */
@@ -60,9 +64,9 @@ Rcpp::NumericMatrix rcpp_segIBDandN(std::string pathThisBreed, std::string pathN
   fN = fopen(pathNative.c_str(),"r");
   if(fC == NULL){error_return("File opening failed.");};
   if(fN == NULL){error_return("File opening failed.");};
-  fgets(Line,2000000,fN);
+  while(fgetc(fN)!='\n'){}
   for(i=0;i<skip+1;i++){
-    fgets(Line,2000000,fC);
+    while(fgetc(fC)!='\n'){}
   }
   endoffile=0;
   m=0;
@@ -171,13 +175,13 @@ Rcpp::NumericMatrix rcpp_segIBDandN(std::string pathThisBreed, std::string pathN
   free(fROH);
   free(thisROH);
   free(lSEG);
-  
   free(kb);
   free(Pos);
   free(indexC);
   free(indexN);
   free(prevAllelesC);
   free(currAllelesC);
+  free(Line);
   
   return confROH;
 }
